@@ -1,39 +1,28 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_INCIDENCEDIALOG_H
 #define INCIDENCEEDITOR_INCIDENCEDIALOG_H
 
-#include "incidenceeditor_export.h"
 #include "editoritemmanager.h"
+#include "incidenceeditor_export.h"
 
 #include <QDate>
 #include <QDialog>
 
 class QAbstractButton;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDialogPrivate;
 /**
  * @brief The IncidenceDialog class
@@ -90,6 +79,7 @@ Q_SIGNALS:
      */
     void incidenceCreated(const Akonadi::Item &);
     void invalidCollection() const;
+
 protected:
     void closeEvent(QCloseEvent *event) override;
 
@@ -107,11 +97,8 @@ private:
     void readConfig();
 
     Q_PRIVATE_SLOT(d_ptr, void handleAlarmCountChange(int))
-    Q_PRIVATE_SLOT(d_ptr, void handleItemSaveFinish(
-                       IncidenceEditorNG::EditorItemManager::SaveAction))
-    Q_PRIVATE_SLOT(d_ptr,
-                   void handleItemSaveFail(IncidenceEditorNG::EditorItemManager::SaveAction,
-                                           QString))
+    Q_PRIVATE_SLOT(d_ptr, void handleItemSaveFinish(IncidenceEditorNG::EditorItemManager::SaveAction))
+    Q_PRIVATE_SLOT(d_ptr, void handleItemSaveFail(IncidenceEditorNG::EditorItemManager::SaveAction, QString))
     Q_PRIVATE_SLOT(d_ptr, void handleRecurrenceChange(IncidenceEditorNG::RecurrenceType))
     Q_PRIVATE_SLOT(d_ptr, void loadTemplate(QString))
     Q_PRIVATE_SLOT(d_ptr, void saveTemplate(QString))
